summaryrefslogtreecommitdiff
path: root/chromium/ash/wm/window_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/ash/wm/window_util.h')
-rw-r--r--chromium/ash/wm/window_util.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chromium/ash/wm/window_util.h b/chromium/ash/wm/window_util.h
index 1ffeb7db8a3..659d3e11e2d 100644
--- a/chromium/ash/wm/window_util.h
+++ b/chromium/ash/wm/window_util.h
@@ -108,16 +108,16 @@ ASH_EXPORT const gfx::Rect* GetPreAutoManageWindowBounds(
ASH_EXPORT void SetPreAutoManageWindowBounds(aura::Window* window,
const gfx::Rect& bounds);
// Move the given bounds inside the given work area, including a safety margin
// given by |kMinimumOnScreenArea|.
ASH_EXPORT void AdjustBoundsToEnsureMinimumWindowVisibility(
- const gfx::Rect& work_area,
+ const gfx::Rect& visible_area,
gfx::Rect* bounds);
// Move the given bounds inside the given work area, including a safety margin
// given by |min_width| and |min_height|.
ASH_EXPORT void AdjustBoundsToEnsureWindowVisibility(
- const gfx::Rect& work_area,
+ const gfx::Rect& visible_area,
int min_width,
int min_height,
gfx::Rect* bounds);
@@ -108,16 +108,16 @@ ASH_EXPORT const gfx::Rect* GetPreAutoManageWindowBounds(
ASH_EXPORT void SetPreAutoManageWindowBounds(aura::Window* window,
const gfx::Rect& bounds);
-// Move the given bounds inside the given work area, including a safety margin
-// given by |kMinimumOnScreenArea|.
+// Move the given bounds inside the given |visible_area|, including a
+// safety margin given by |kMinimumOnScreenArea|.
ASH_EXPORT void AdjustBoundsToEnsureMinimumWindowVisibility(
@@ -108,16 +108,16 @@ ASH_EXPORT const gfx::Rect* GetPreAutoManageWindowBounds(
gfx::Rect* bounds);
-// Move the given bounds inside the given work area, including a safety margin
-// given by |min_width| and |min_height|.
+// Move the given bounds inside the given |visible_area|, including a
+// safety margin given by |min_width| and |min_height|.
ASH_EXPORT void AdjustBoundsToEnsureWindowVisibility(